#ifndef COPYTODIALOG_H
#define COPYTODIALOG_H

#include <QDialog>

namespace Ui {
    class copyToDialog;
}

class copyToDialog : public QDialog
{
    Q_OBJECT

    friend class wpNew;

public:
    explicit copyToDialog(QWidget *parent = 0);
    ~copyToDialog();

protected:
    Ui::copyToDialog *ui;
};

#endif // COPYTODIALOG_H
